use `chuanshan-platform`;

-- ----------------------------
-- 区域
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_area`;
CREATE TABLE `mortals_sys_area`
(
    `id`                bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
    `ancestors`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT '' COMMENT '祖级列表，逗号分隔',
    `name`              varchar(64)                                             DEFAULT NULL COMMENT '区域名称',
    `iid`               char(32)                                                DEFAULT NULL COMMENT '一体化的ID号',
    `pid`               char(32)                                                DEFAULT NULL COMMENT '一体化的父id',
    `haveSonArea`       char(5)                                                 DEFAULT NULL COMMENT '是否有下级区域（True.是，False.否）',
    `haveSonDept`       char(5)                                                 DEFAULT NULL COMMENT '是否有下级部门（True.是，False.否）',
    `haveGetDept`       char(5)                                                 DEFAULT NULL COMMENT '是否获取部门（true.是，false.否）',
    `haveGetMatterList` char(5)                                                 DEFAULT NULL COMMENT '是否获取事项列表（true.是，false.否）',
    `areaCode`          char(32)                                                DEFAULT NULL COMMENT '区域编码',
    `areaLevel`         tinyint(2) DEFAULT '1' COMMENT '区域等级(1.省，2.地市州，3.区县，4.街道，5.社区)',
    `shortName`         varchar(64)                                             DEFAULT NULL COMMENT '名称简称',
    `domain`            varchar(1024)                                           DEFAULT NULL COMMENT '访问地址',
    `status`            tinyint(2) DEFAULT '1' COMMENT '区域状态 (0.停用，1.正常)',
    `createTime`        datetime                                                DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
    `createUserId`      bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
    `updateTime`        datetime                                                DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '区域表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- 站点表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_site`;
CREATE TABLE mortals_sys_site
(
    `id`                       bigint(20) AUTO_INCREMENT COMMENT '序号，主键，自增长',
    `siteName`                 varchar(255) COMMENT '站点名称',
    `siteCode`                 varchar(64) COMMENT '站点编号',
    `areaID`                   varchar(32) COMMENT '区域Id',
    `areaCode`                 varchar(32) COMMENT '区域编号',
    `areaName`                 varchar(32) COMMENT '区域名称',
    `proCode`                  varchar(32) COMMENT '省编码',
    `cityCode`                 varchar(32) COMMENT '市编码',
    `districtCode`             varchar(32) COMMENT '区编码',
    `siteIp`                   varchar(32) COMMENT '站点服务器ip',
    `sitePort`                 varchar(8) COMMENT '站点服务器端口',
    `longitude`                varchar(32) COMMENT '经度',
    `latitude`                 varchar(32) COMMENT '纬度',
    `siteTel`                  varchar(32) COMMENT '中心联系电话',
    `detailAddress`            varchar(255) COMMENT '中心详细地址',
    `siteRemark`               text COMMENT '中心介绍',
    `amWorkStartTime`          datetime COMMENT '上午上班开始时间',
    `amWorkEndTime`            datetime COMMENT '上午上班结束时间',
    `pmWorkStartTime`          datetime COMMENT '下午上班开始时间',
    `pmWorkEndTime`            datetime COMMENT '下午上班结束时间',
    `workday1`                 tinyint(2) COMMENT '周一 (1.上班，0.不上)',
    `workday2`                 tinyint(2) COMMENT '周二 (1.上班，0.不上)',
    `workday3`                 tinyint(2) COMMENT '周三 (1.上班，0.不上)',
    `workday4`                 tinyint(2) COMMENT '周四 (1.上班，0.不上)',
    `workday5`                 tinyint(2) COMMENT '周五 (1.上班，0.不上)',
    `workday6`                 tinyint(2) COMMENT '周六 (1.上班，0.不上)',
    `workday7`                 tinyint(2) COMMENT '周日 (1.上班，0.不上)',
    `level`                    int(4) COMMENT '楼层',
    `building`                 int(4) COMMENT '楼栋',
    `logoPath`                 varchar(255) COMMENT 'logo图片地址',
    `englishName`              varchar(255) COMMENT '英文名称',
    `leadingOfficial`          varchar(64) COMMENT '负责人',
    `leadingOfficialTelephone` varchar(64) COMMENT '联系电话',
    `modelIds`                 varchar(256) COMMENT '部署模块，逗号分隔',
    `createTime`               datetime COMMENT '创建时间',
    `createUserId`             bigint(20) COMMENT '创建用户',
    `updateTime`               datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='站点';



-- ----------------------------
-- 站点事项表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_site_matter`;
CREATE TABLE mortals_sys_site_matter
(
    `id`            bigint(20) AUTO_INCREMENT COMMENT '序号，主键，自增长',
    `siteId`        bigint(20) COMMENT '站点ID',
    `siteName`      varchar(255) COMMENT '站点名称',
    `matterId`      bigint(20) COMMENT '事项ID',
    `matterName`    varchar(1024) COMMENT '事项名称',
    `matterCode`    varchar(512) COMMENT '事项编码',
    `deptId`        bigint(20) COMMENT '部门ID',
    `deptName`      varchar(64) COMMENT '部门名称',
    `eventTypeShow` varchar(255) COMMENT '事项类型',
    `source`        tinyint(2) COMMENT '事项来源',
    `deptCode`      varchar(255) COMMENT '部门编号',
    `createTime`    datetime COMMENT '创建时间',
    `createUserId`  bigint(20) COMMENT '创建用户',
    `updateTime`    datetime COMMENT '修改时间',
    PRIMARY KEY (`id`),
    KEY             `mattercode` (`matterCode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='站点事项';


-- ----------------------------
-- 部门表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_dept`;
CREATE TABLE mortals_sys_dept
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '序号，主键，自增长',
    `tid`          varchar(128) COMMENT '从政务系统来的部门id',
    `tname`        varchar(128) COMMENT '从政务系统来的部门name',
    `name`         varchar(64) COMMENT '部门名称',
    `simpleName`   varchar(128) COMMENT '从政务系统来的别名',
    `siteId`       bigint(20) COMMENT '站点ID',
    `deptAbb`      varchar(32) COMMENT '部门简称',
    `deptTelphone` varchar(32) COMMENT '部门电话',
    `deptNumber`   varchar(32) COMMENT '部门编号',
    `isAutotable`  tinyint(1) COMMENT '填单机展示 (0.否，1.是) ',
    `isOrder`      tinyint(1) COMMENT '预约展示 (0.否，1.是) ',
    `isBkb`        tinyint(1) COMMENT '背靠背展示 (0.否，1.是) ',
    `isWorkGuide`  tinyint(1) COMMENT '办事指南展示 (0.否，1.是) ',
    `usValid`      tinyint(1) COMMENT '是否使用 (0.否，1.是) ',
    `isSecphone`   tinyint(1) COMMENT '部门电话是否展示 (0.否，1.是) ',
    `isEnglish`    tinyint(1) COMMENT '是否展示英文 (0.否，1.是) ',
    `sort`         int(4) COMMENT '排序',
    `source`       tinyint(2) COMMENT '部门来源',
    `createTime`   datetime COMMENT '创建时间',
    `createUserId` bigint(20) COMMENT '创建用户',
    `updateTime`   datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='部门';

-- ----------------------------
-- 基础事项表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter`;
CREATE TABLE mortals_sys_matter
(
    `id`                        bigint(20) AUTO_INCREMENT COMMENT '序号，主键，自增长',
    `siteId`                    bigint(20) COMMENT '站点ID',
    `tid`                       varchar(256) COMMENT '从政务系统来的事项id',
    `tcode`                     varchar(256) COMMENT '从政务系统来的事项code',
    `tname`                     varchar(2048) COMMENT '从政务系统来的事项name',
    `matterName`                varchar(2048) COMMENT '事项名称',
    `englishName`               varchar(256) COMMENT '英语事项名',
    `matterNo`                  varchar(512) COMMENT '事项编号',
    `areaCode`                  varchar(255) COMMENT '区域编码',
    `deptCode`                  varchar(255) COMMENT '部门编号',
    `deptName`                  varchar(255) COMMENT '部门名称',
    `powerCode`                 varchar(255) COMMENT '行政权力编号',
    `themeCode`                 varchar(255) COMMENT '主题编号',
    `usertypeCode`              varchar(255) COMMENT '服务类型编号',
    `groupName`                 varchar(255) COMMENT '事项组名',
    `url`                       varchar(1024) COMMENT '事项详情链接',
    `haveGetMatterInfo`         varchar(20) COMMENT '是否获取事项详情',
    `belongDept`                varchar(64) COMMENT '所属部门',
    `appoveObjectShow`          varchar(16) COMMENT '服务对象 （事业法人.事业法人，社会组织法人.社会组织法人，非法人企业.非法人企业，企业法人.企业法人，自然人.自然人，其他组织.其他组织）',
    `operatScopeShow`           varchar(64) COMMENT '通办范围 （无.无，全国.全国，全市.全市，全县.全县，全镇[乡 街道].全镇[乡 街道]，跨村[社区].跨村[社区]）',
    `appoveTimeLimitShow`       varchar(16) COMMENT '办件类型（网络办件.网络办件，行政审批一般件.行政审批一般件，综合窗口件.综合窗口件）',
    `handleType`                varchar(12) COMMENT '办理形式（窗口办理.窗口办理，网上办理.网上办理）	',
    `legalTimeLimitShow`        varchar(32) COMMENT '法定办结时限',
    `legalEndExplain`           varchar(255) COMMENT '法定时限办结说明',
    `promiseTimeLimitShow`      varchar(32) COMMENT '承诺办结时限',
    `promiseEndExplain`         varchar(255) COMMENT '承诺时限办结说明',
    `isChargesShow`             varchar(16) COMMENT '是否收费（否.否，是.是）',
    `certificationLevelsShow`   varchar(64) COMMENT '认证等级需求（实名认证.实名认证，单次面签.单次面签，每次面签.每次面签）',
    `planTakeTime`              datetime COMMENT '计划生效日期',
    `promiseTakeTime`           datetime COMMENT '承诺生效日期',
    `specialProcedure`          varchar(64) COMMENT '特别程序',
    `windowToTheSceneNum`       tinyint(2) COMMENT '窗口到现场次数',
    `isOnlineSubscribeShow`     varchar(64) COMMENT '是否网上预约,窗口办理选（否.否，是.是）',
    `isExpressTakeShow`         varchar(16) COMMENT '物流快递,窗口办理选（否.否，是.是）',
    `isProvinceAcquisitionShow` varchar(16) COMMENT '是否支持全省范围就近取件（否.否，是.是）',
    `isApplyProvinceShow`       varchar(16) COMMENT '是否支持全省范围就近办理（否.否，是.是）',
    `mustSceneExplain`          varchar(512) COMMENT '必须到现场原因',
    `onlineType`                varchar(32) COMMENT '网办类型（原件预审.原件预审，原件核验.原件核验，全程网办.全程网办）',
    `onlineToTheSceneNum`       tinyint(2) COMMENT '网办到现场次数',
    `onlineOperatDeep`          varchar(16) COMMENT '网络办理深度（互联网咨询.互联网咨询，互联网收件.互联网收件，互联网预审.互联网预审，互联网受理.互联网受理，互联网办理.互联网办理，互联网办理结果信息反馈.互联网办理结果信息反馈，其他.其他）',
    `isExpressTakeOnlineShow`   varchar(16) COMMENT '物流快递，网上办理选（否.否，是.是）',
    `isDoorTakeShow`            varchar(16) COMMENT '是否支持上门收取申请（否.否，是.是）',
    `onlineMustSceneExplain`    varchar(512) COMMENT '网上必须到现场原因',
    `performDeptType`           varchar(64) COMMENT '实施主体',
    `matterEdition`             varchar(32) COMMENT '事项版本',
    `eventTypeShow`             varchar(128) COMMENT '事项类型名称（行政许可.行政许可，行政处罚.行政处罚，行政强制.行政强制，行政征收.行政征收，行政给付.行政给付，行政检查.行政检查，行政确认.行政确认，行政奖励.行政奖励，行政裁决.行政裁决，其他行政权力.其他行政权力，主动服务.主动服务，依申请服务.依申请服务，咨询查询.咨询查询，未归类事项.未归类事项）',
    `performHierarchyShow`      varchar(128) COMMENT '行使层级名称（省级.省级，市级.市级，县级.县级，镇[乡 街道].镇[乡 街道]，村[社区]级.村[社区]级）',
    `powerSourceShow`           varchar(64) COMMENT '权力来源（法定本级行使.法定本级行使，上级下放.上级下放，上级授权.上级授权，同级授权.同级授权，上级委托.上级委托，同级委托.同级委托）',
    `performDeptTypeShow`       varchar(64) COMMENT '实施主体性质（法定机关.法定机关，授权组织.授权组织，受委托组织.受委托组织）',
    `goveServiceCenterShow`     varchar(16) COMMENT '是否进驻中心（否.否，是.是）',
    `isConvenientCenterShow`    varchar(16) COMMENT '是否纳入便民服务中心（否.否，是.是）',
    `terminalHandle`            varchar(20) COMMENT '自助终端办理 （否.否，是.是）',
    `isOnline`                  varchar(20) COMMENT '是否网办 （否.否，是.是）',
    `isOnlinePayShow`           varchar(16) COMMENT '支持网上支付（否.否，是.是）',
    `entrustmentDepartmen`      varchar(64) COMMENT '委托部门（否.否，是.是）',
    `jointInfoShow`             varchar(128) COMMENT '联办机构',
    `matterStatus`              varchar(32) COMMENT '事项状态（停用.停用，在用.在用）',
    `numberLimit`               int(11) COMMENT '数量限制',
    `type`                      varchar(32) COMMENT '主题类型',
    `baseCode`                  varchar(128) COMMENT '基本编码',
    `implementCode`             varchar(128) COMMENT '实施编码',
    `implementBodyCode`         varchar(128) COMMENT '实施主体编码',
    `operateItemCode`           varchar(128) COMMENT '办理项编码',
    `townshipName`              varchar(128) COMMENT '乡镇街道名称',
    `townshipCode`              varchar(128) COMMENT '乡镇街道代码',
    `villageName`               varchar(128) COMMENT '村居社区名称',
    `villageCode`               varchar(128) COMMENT '村居社区代码',
    `operateTime`               varchar(128) COMMENT '办理时间',
    `operateSite`               varchar(1024) COMMENT '办理地点',
    `cousultingShow`            varchar(1024) COMMENT '咨询方式',
    `cousultingTelephoneShow`   varchar(64) COMMENT '咨询电话',
    `superviseShow`             varchar(1024) COMMENT '监督投诉方式',
    `sort`                      int(4) COMMENT '排序',
    `source`                    tinyint(2) COMMENT '事项来源(0.政务网，1.自定义)',
    `evaluationUrl` varchar(1024)      COMMENT '评价地址',
    `netApplyUrl` varchar(1024)      COMMENT '申请地址',
    `createTime`                datetime COMMENT '创建时间',
    `createUserId`              bigint(20) COMMENT '创建用户',
    `updateTime`                datetime COMMENT '修改时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `站点事项编码` (`matterNo`,`areaCode`) USING BTREE,
    KEY                         `区域` (`areaCode`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='基础事项';



-- ----------------------------
-- 事项受理条件表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_accept`;
CREATE TABLE mortals_sys_matter_accept
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `matterId`     bigint(20) NOT NULL COMMENT '基础事项表id',
    `matterCode`   varchar(512) COMMENT '事项编码',
    `matterName`   varchar(1024) COMMENT '事项名称',
    `content`      text COMMENT '受理条件',
    `source`       tinyint(2) COMMENT '事项来源 (0.政务网，1.自定义)',
    `createTime`   datetime COMMENT '创建时间',
    `createUserId` bigint(20) COMMENT '创建用户',
    `updateTime`   datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项受理条件';

-- ----------------------------
-- 事项收费标准表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_charges`;
CREATE TABLE mortals_sys_matter_charges
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `matterId`     bigint(20) NOT NULL COMMENT '事项基础表matter id',
    `matterCode`   varchar(512) COMMENT '事项编码',
    `matterName`   varchar(1024) COMMENT '事项名称',
    `content`      varchar(1024) COMMENT '收费标准',
    `source`       tinyint(2) COMMENT '事项来源，(0.政务网，1.自定义)',
    `createTime`   datetime COMMENT '创建时间',
    `createUserId` bigint(20) COMMENT '创建用户',
    `updateTime`   datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项收费标准';

-- ----------------------------
-- 事项申请材料表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_datum`;
CREATE TABLE mortals_sys_matter_datum
(
    `id`               bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `matterId`         bigint(20) COMMENT '事项id',
    `matterCode`       varchar(512) COMMENT '事项编码',
    `matterName`       varchar(1024) COMMENT '事项名称',
    `materialName`     varchar(1024) NOT NULL COMMENT '材料名',
    `isMust`           varchar(32) COMMENT '必交性（非必要.非必要，必要.必要，必要|容缺后补.必要|容缺后补，非必要|容缺后补.非必要|容缺后补）',
    `materialType`     varchar(32) COMMENT '材料类型（无.无，原件.原件，复印件.复印件，原件和复印件.原件和复印件)',
    `materialProperty` varchar(32) COMMENT '材料形式（纸质.纸质，电子.电子，纸质|电子.纸质|电子）',
    `electronicgs`     varchar(32) COMMENT '电子材料格式（无.无，不限.不限，jpg.jpg，jpeg.jpeg，pdf.pdf，word.word，pdf|jpg|jpeg.pdf|jpg|jpeg，pdf|jpg.pdf|jpg）',
    `materialSource`   varchar(32) COMMENT '材料来源渠道（无.无，申请人自备.申请人自备，政府部门核发.政府部门核发，其他.其他）',
    `paperNum`         tinyint(4) COMMENT '纸质材料份数',
    `paperGg`          varchar(32) COMMENT '纸质材料规格',
    `jianmMs`          varchar(32) COMMENT '减免模式（无.无，减.减，免.免）',
    `sealWay`          varchar(128) COMMENT '盖章方式',
    `isjianm`          varchar(32) COMMENT '是否减免（否.否，是.是）',
    `isLack`           varchar(32) COMMENT '材料是否容缺（必要.必要，非必要.非必要）',
    `ybUrl`            varchar(512) COMMENT '材料地址',
    `materialSourceSm` varchar(512) COMMENT '来源渠道说明',
    `remarkSub`        text COMMENT '填报须知',
    `clauseContent`    text COMMENT '要求提供材料的依据',
    `summary`          text COMMENT '受理标准',
    `remark`           varchar(4096) COMMENT '备注',
    `source`           tinyint(2) COMMENT '事项来源(0.政务网，1.自定义)',
    `createTime`       datetime COMMENT '创建时间',
    `createUserId`     bigint(20) COMMENT '创建用户',
    `updateTime`       datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项申请材料';


-- ----------------------------
-- 材料附件表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_datum_file`;
CREATE TABLE mortals_sys_matter_datum_file
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `datumId`      bigint(20) COMMENT '材料id',
    `matterCode`   varchar(255) COMMENT '事项编码',
    `materialName` varchar(1024) NOT NULL COMMENT '材料名',
    `fileName`     varchar(255) COMMENT '附件名称',
    `fileUrl`      varchar(255) COMMENT '附件下载地址',
    `localFileUrl` varchar(255) COMMENT '附件本地下载地址',
    `filetype`     varchar(64) COMMENT '附件类型 (示例样表.示例样表，空白表格.空白表格)',
    `source`       tinyint(2) COMMENT '附件来源 (0.政务网，1.自定义)',
    `createTime`   datetime COMMENT '创建时间',
    `createUserId` bigint(20) COMMENT '创建用户',
    `updateTime`   datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='材料附件';


-- ----------------------------
-- 事项中介服务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_intermediary`;
CREATE TABLE mortals_sys_matter_intermediary
(
    `id`                      bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `matterId`                bigint(20) NOT NULL COMMENT '事项matter id',
    `matterCode`              varchar(512) COMMENT '事项编码',
    `matterName`              varchar(1024) COMMENT '事项名称',
    `title`                   varchar(1024) COMMENT '中介服务事项名称',
    `intermediaryRequest`     text COMMENT '中介服务实施机构及资质资格要求',
    `intermediaryRequestTime` varchar(512) COMMENT '服务时限',
    `remark`                  text COMMENT '内容',
    `source`                  tinyint(2) COMMENT '事项来源，(0.政务网，1.自定义)',
    `createTime`              datetime COMMENT '创建时间',
    `createUserId`            bigint(20) COMMENT '创建用户',
    `updateTime`              datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项中介服务';

-- ----------------------------
-- 事项常见问题表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_question`;
CREATE TABLE mortals_sys_matter_question
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `matterId`     bigint(20) NOT NULL COMMENT '事项基础表matter id',
    `matterCode`   varchar(512) COMMENT '事项编码',
    `matterName`   varchar(1024) COMMENT '事项名称',
    `question`     varchar(512) COMMENT '问题',
    `answer`       varchar(2048) COMMENT '常见问题',
    `source`       tinyint(2) COMMENT '事项来源，(0.政务网，1.自定义)',
    `createTime`   datetime COMMENT '创建时间',
    `createUserId` bigint(20) COMMENT '创建用户',
    `updateTime`   datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项常见问题';

-- ----------------------------
-- 事项设定依据表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_setbase`;
CREATE TABLE mortals_sys_matter_setbase
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `matterId`     bigint(20) NOT NULL COMMENT '事项matter id',
    `matterCode`   varchar(255) COMMENT '事项编码',
    `matterName`   varchar(1024) COMMENT '事项名称',
    `policyName`   varchar(1024) COMMENT '法规标题',
    `policyType`   varchar(32) COMMENT '法规类型，(法律.法律，行政法规.行政法规，地方法规.地方法规，部门规章.部门规章，其他.其他，政府规章.政府规章，规范性文件.规范性文件)',
    `policyitem`   varchar(1024) COMMENT '条例',
    `content`      text COMMENT '条款内容',
    `source`       tinyint(2) COMMENT '事项来源，(0.政务网，1.自定义)',
    `createTime`   datetime COMMENT '创建时间',
    `createUserId` bigint(20) COMMENT '创建用户',
    `updateTime`   datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项设定依据';

-- ----------------------------
-- 事项办理流程表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_flowlimit`;
CREATE TABLE mortals_sys_matter_flowlimit
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `matterId`     bigint(20) NOT NULL COMMENT '事项基础表id',
    `matterCode`   varchar(512) COMMENT '事项编码',
    `matterName`   varchar(1024) COMMENT '事项名称',
    `flowName`     varchar(256) COMMENT '办理流程',
    `flowTime`     varchar(256) COMMENT '办理时长',
    `flowLimit`    varchar(256) COMMENT '转外时限',
    `flowDesc`     varchar(1024) COMMENT '办理流程说明',
    `source`       tinyint(2) COMMENT '事项来源(0.政务网，1.自定义)',
    `createTime`   datetime COMMENT '创建时间',
    `createUserId` bigint(20) COMMENT '创建用户',
    `updateTime`   datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项办理流程';


-- ----------------------------
-- 事项扩展表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_ext`;
CREATE TABLE mortals_sys_matter_ext
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '主键，自增长',
    `matterId`     bigint(20) NOT NULL COMMENT '事项基础表matter id',
    `matterCode`   varchar(512) COMMENT '事项编码',
    `matterName`   varchar(1024) COMMENT '事项名称',
    `fieldCode`    varchar(256) COMMENT '字段编码',
    `fieldName`    varchar(256) COMMENT '字段名称',
    `fieldValue`   varchar(1024) COMMENT '字段值',
    `fieldType`    varchar(64) COMMENT '字段类型',
    `fieldOrderNo` int(11) COMMENT '字段排序号',
    `source`       tinyint(2) COMMENT '事项来源，(0.政务网，1.自定义)',
    `createTime`   datetime COMMENT '创建时间',
    `createUserId` bigint(20) COMMENT '创建用户',
    `updateTime`   datetime COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项扩展';


-- ----------------------------
-- Table structure for mortals_iot_area
-- ----------------------------
DROP TABLE IF EXISTS `mortals_iot_area`;
CREATE TABLE `mortals_iot_area` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'id号',
  `areaCode` char(32) DEFAULT NULL COMMENT '区域编码',
  `name` varchar(64) DEFAULT NULL COMMENT '区域名称',
  `areaLevel` char(2) DEFAULT NULL COMMENT '区域等级，1省，2地市州，3区县，4街道，5社区',
  `haveSonArea` char(5) DEFAULT NULL COMMENT '是否有下级区域',
  `haveSonDept` char(5) DEFAULT NULL COMMENT '是否有下级部门',
  `shortName` varchar(64) DEFAULT NULL COMMENT '名称简称',
  `domain` varchar(1024) DEFAULT NULL COMMENT '访问地址',
  `iid` char(32) DEFAULT NULL COMMENT '一体化的ID号',
  `pid` char(32) DEFAULT NULL COMMENT '一体化的父id',
  `haveGetDept` char(5) DEFAULT NULL COMMENT '是否获取部门',
  `haveGetMatterList` char(5) DEFAULT NULL COMMENT '是否获取事项列表',
  `updateTime` datetime DEFAULT NULL COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=MyISAM AUTO_INCREMENT=36358 DEFAULT CHARSET=utf8 COMMENT='区域表';

-- ----------------------------
-- Table structure for mortals_iot_matters
-- ----------------------------
DROP TABLE IF EXISTS `mortals_iot_matters`;
CREATE TABLE `mortals_iot_matters` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'id号',
  `areaCode` char(32) DEFAULT NULL COMMENT '区域编码',
  `deptCode` char(32) DEFAULT NULL COMMENT '部门编号',
  `powerCode` char(3) DEFAULT NULL COMMENT '行政权力编号',
  `themeCode` char(128) DEFAULT NULL COMMENT '主题编号',
  `usertypeCode` char(3) DEFAULT NULL COMMENT '服务类型编号',
  `matterCode` char(64) DEFAULT NULL COMMENT '事项编号',
  `name` varchar(256) DEFAULT NULL COMMENT '事项名称',
  `groupName` varchar(256) DEFAULT NULL COMMENT '事项组名',
  `url` varchar(1024) DEFAULT NULL COMMENT '事项详情链接',
  `haveGetMatterInfo` char(5) DEFAULT NULL COMMENT '是否获取事项详情',
  `updateTime` datetime DEFAULT NULL COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=MyISAM AUTO_INCREMENT=6079 DEFAULT CHARSET=utf8 COMMENT='事项列表';

-- ----------------------------
-- Table structure for mortals_iot_matters_dept
-- ----------------------------
DROP TABLE IF EXISTS `mortals_iot_matters_dept`;
CREATE TABLE `mortals_iot_matters_dept` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'id号',
  `areaCode` char(32) DEFAULT NULL COMMENT '区域编号',
  `deptCode` char(32) DEFAULT NULL COMMENT '部门编号',
  `name` varchar(256) DEFAULT NULL COMMENT '部门名称',
  `updateTime` datetime DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=MyISAM AUTO_INCREMENT=35 DEFAULT CHARSET=utf8 COMMENT='部门表';

-- ----------------------------
-- Table structure for mortals_iot_matters_detail
-- ----------------------------
DROP TABLE IF EXISTS `mortals_iot_matters_detail`;
CREATE TABLE `mortals_iot_matters_detail` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'id号',
  `matterCode` char(64) DEFAULT NULL COMMENT '事项编号',
  `onlineUrl_zxsq` varchar(1024) DEFAULT NULL COMMENT '在线申请',
  `basicInfo_jbxx` text COMMENT '基本信息',
  `materials_sqcl` text COMMENT '申请材料',
  `conditions_sltj` text COMMENT '受理条件',
  `process_bllc` text COMMENT '办理流程',
  `charging_sfbz` text COMMENT '收费标准',
  `basis_sdyj` text COMMENT '设定依据',
  `intermediary_zjfw` text COMMENT '中介服务',
  `question_cjwt` text COMMENT '常见问题',
  `updateTime` datetime DEFAULT NULL COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=MyISAM AUTO_INCREMENT=6079 DEFAULT CHARSET=utf8 COMMENT='事项详情表';

-- ----------------------------
-- Table structure for mortals_iot_matters_power
-- ----------------------------
DROP TABLE IF EXISTS `mortals_iot_matters_power`;
CREATE TABLE `mortals_iot_matters_power` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'id号',
  `powerCode` char(3) DEFAULT NULL COMMENT '行政权力编号',
  `name` varchar(64) DEFAULT NULL COMMENT '行政权力名称',
  `updateTime` datetime DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8 COMMENT='行政权力表';

-- ----------------------------
-- Table structure for mortals_iot_matters_theme
-- ----------------------------
DROP TABLE IF EXISTS `mortals_iot_matters_theme`;
CREATE TABLE `mortals_iot_matters_theme` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'id号',
  `usertypeCode` char(3) DEFAULT NULL COMMENT '服务类型编号',
  `themeCode` char(3) DEFAULT NULL COMMENT '主题编号',
  `name` varchar(64) DEFAULT NULL COMMENT '主题名称',
  `updateTime` datetime DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=MyISAM AUTO_INCREMENT=67 DEFAULT CHARSET=utf8 COMMENT='主题表';

-- ----------------------------
-- Table structure for mortals_iot_matters_usertype
-- ----------------------------
DROP TABLE IF EXISTS `mortals_iot_matters_usertype`;
CREATE TABLE `mortals_iot_matters_usertype` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'id号',
  `usertypeCode` char(3) DEFAULT NULL COMMENT '服务类型编号',
  `name` varchar(64) DEFAULT NULL COMMENT '服务类型名称',
  `updateTime` datetime DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COMMENT='服务类型表';


-- ----------------------------
-- 材料公共库表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_public_library`;
CREATE TABLE mortals_xhx_public_library(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `siteId` bigint(20)      COMMENT '站点id',
    `simpleName` varchar(128) NOT NULL     COMMENT '材料简称',
    `fullName` varchar(128) NOT NULL     COMMENT '材料全称',
    `fileUrl` varchar(128)      COMMENT '文件地址',
    `previewUrl` varchar(128)      COMMENT '文件预览地址',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='材料公共库';


-- ----------------------------
-- 纠错管理表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_error_recovery`;
CREATE TABLE mortals_xhx_error_recovery(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `siteId` bigint(20)      COMMENT '站点id',
    `errorTitle` varchar(128) NOT NULL     COMMENT '纠错标题',
    `matterSite` varchar(128)      COMMENT '事件位置',
    `substance` text    DEFAULT '1'  COMMENT '具体内容',
    `annexUrl` varchar(255)      COMMENT '附件地址',
    `formalReply` text      COMMENT '建议答复',
    `submitUserId` bigint(20)      COMMENT '纠错用户id',
    `submitUserName` varchar(128)      COMMENT '纠错用户名称',
    `submitDate` datetime NOT NULL     COMMENT '提交时间',
    `status` tinyint(2)    DEFAULT '0'  COMMENT '处理状态，0：未处理，1：已处理',
    `answerUserId` bigint(20)      COMMENT '处理用户id',
    `answerUserName` varchar(128)      COMMENT '处理用户名称',
    `answerDate` datetime      COMMENT '处理时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='纠错管理';


-- ----------------------------
-- 股室管理表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_dept_office`;
CREATE TABLE mortals_xhx_dept_office(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `siteId` bigint(20)      COMMENT '站点id',
    `deptId` bigint(20)      COMMENT '所属部门',
    `deptName` varchar(128)      COMMENT '所属部门名称',
    `officeName` varchar(128)      COMMENT '股室名称',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='股室管理';

-- ----------------------------
-- 用户收藏夹表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_user_collect`;
CREATE TABLE mortals_xhx_user_collect(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `userId` bigint(20)      COMMENT '用户id',
    `collectType` tinyint(2)    DEFAULT '1'  COMMENT '收藏类型1单事项2一件事',
    `collectName` varchar(128)      COMMENT '收藏名称',
    `collectUrl` varchar(128)      COMMENT '收藏链接',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户收藏夹';